@@ -26,7 +26,7 @@ from ansible_compat.errors import (
     InvalidPrerequisiteError,
     MissingAnsibleError,
 )
-from ansible_compat.loaders import yaml_from_file
+from ansible_compat.loaders import colpath_from_path, yaml_from_file
 from ansible_compat.prerun import get_cache_dir
 
 if TYPE_CHECKING:
@@ -85,8 +85,11 @@ class Runtime:
         # Reduce noise from paramiko, unless user already defined PYTHONWARNINGS
         # paramiko/transport.py:236: CryptographyDeprecationWarning: Blowfish has been deprecated
         # https://github.com/paramiko/paramiko/issues/2038
+        # As CryptographyDeprecationWarning is not a builtin, we cannot use
+        # PYTHONWARNINGS to ignore it using category but we can use message.
+        # https://stackoverflow.com/q/68251969/99834
         if "PYTHONWARNINGS" not in self.environ:
-            self.environ["PYTHONWARNINGS"] = "ignore::CryptographyDeprecationWarning"
+            self.environ["PYTHONWARNINGS"] = "ignore:Blowfish has been deprecated"
 
         if isolated:
             self.cache_dir = get_cache_dir(self.project_dir)
@@ -266,7 +269,10 @@ class Runtime:
                     force=True,
                 )
 
-    def install_requirements(self, requirement: str, retry: bool = False) -> None:
+    # pylint: disable=too-many-branches
+    def install_requirements(
+        self, requirement: str, retry: bool = False, offline: bool = False
+    ) -> None:
         """Install dependencies from a requirements.yml."""
         if not os.path.exists(requirement):
             return
@@ -287,11 +293,16 @@ class Runtime:
             if self.cache_dir:
                 cmd.extend(["--roles-path", f"{self.cache_dir}/roles"])
 
-            _logger.info("Running %s", " ".join(cmd))
-            run = self.exec(cmd, retry=retry)
-            if run.returncode != 0:
-                _logger.error(run.stdout)
-                raise AnsibleCommandError(run)
+            if offline:
+                _logger.warning(
+                    "Role installation skipped because `ansible-galaxy role install` command does not support an offline mode."
+                )
+            else:
+                _logger.info("Running %s", " ".join(cmd))
+                result = self.exec(cmd, retry=retry)
+                if result.returncode != 0:
+                    _logger.error(result.stdout)
+                    raise AnsibleCommandError(result)
 
         # Run galaxy collection install works on v2 requirements.yml
         if "collections" in reqs_yaml:
@@ -300,19 +311,29 @@ class Runtime:
                 "ansible-galaxy",
                 "collection",
                 "install",
-                "-vr",
-                f"{requirement}",
+                "-v",
             ]
-            if self.cache_dir:
-                cmd.extend(["-p", f"{self.cache_dir}/collections"])
+            skip = False
+            if offline:
+                if self.version_in_range(upper="2.14"):
+                    _logger.warning(
+                        "Collection install skipped because ansible versions before 2.14 do not support an offline mode."
+                    )
+                    skip = True
+                else:
+                    cmd.append("--offline")
+            if not skip:
+                cmd.extend(["-r", requirement])
+                if self.cache_dir:
+                    cmd.extend(["-p", f"{self.cache_dir}/collections"])
+                _logger.info("Running %s", " ".join(cmd))
+                result = self.exec(cmd, retry=retry)
+                if result.returncode != 0:
+                    _logger.error(result.stdout)
+                    _logger.error(result.stderr)
+                    raise AnsibleCommandError(result)
 
-            _logger.info("Running %s", " ".join(cmd))
-            run = self.exec(cmd, retry=retry)
-            if run.returncode != 0:
-                _logger.error(run.stdout)
-                raise AnsibleCommandError(run)
-
-    def prepare_environment(
+    def prepare_environment(  # noqa: C901
         self,
         required_collections: Optional[Dict[str, str]] = None,
         retry: bool = False,
@@ -324,17 +345,16 @@ class Runtime:
         if required_collections is None:
             required_collections = {}
 
-        if not offline:
-            # first one is standard for collection layout repos and the last two
-            # are part of Tower specification
-            # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
-            # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#collections-support
-            for req_file in [
-                "requirements.yml",
-                "roles/requirements.yml",
-                "collections/requirements.yml",
-            ]:
-                self.install_requirements(req_file, retry=retry)
+        # first one is standard for collection layout repos and the last two
+        # are part of Tower specification
+        # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
+        # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#collections-support
+        for req_file in [
+            "requirements.yml",
+            "roles/requirements.yml",
+            "collections/requirements.yml",
+        ]:
+            self.install_requirements(req_file, retry=retry, offline=offline)
 
         destination = f"{self.cache_dir}/collections" if self.cache_dir else None
         for name, min_version in required_collections.items():
@@ -349,6 +369,21 @@ class Runtime:
             return
 
         if os.path.exists("galaxy.yml"):
+            if destination:
+                # while function can return None, that would not break the logic
+                colpath = f"{destination}/ansible_collections/{colpath_from_path(os.getcwd())}"
+                if os.path.islink(colpath):
+                    if os.path.realpath(colpath) == os.getcwd():
+                        _logger.warning(
+                            "Found symlinked collection, skipping its installation."
+                        )
+                        return
+                    _logger.warning(
+                        "Collection is symlinked, but not pointing to %s directory, so we will remove it.",
+                        os.getcwd(),
+                    )
+                    os.unlink(colpath)
+
             # molecule scenario within a collection
             self.install_collection_from_disk(".", destination=destination)
         elif pathlib.Path().resolve().parent.name == "roles" and os.path.exists(
