@@ -23,7 +23,7 @@ def test_config() -> None:
     assert isinstance(config.CONNECTION_FACTS_MODULES, dict)
     assert config.ANSIBLE_COW_PATH is None
     assert isinstance(config.NETWORK_GROUP_MODULES, list)
-    assert isinstance(config.DEFAULT_GATHER_TIMEOUT, int)
+    assert isinstance(config.DEFAULT_GATHER_TIMEOUT, (int, type(None)))
 
     # check lowercase and older name aliasing
     assert isinstance(config.collections_paths, list)
@@ -94,4 +94,5 @@ def test_ansible_version_missing(monkeypatch: MonkeyPatch) -> None:
         MissingAnsibleError,
         match="Unable to find a working copy of ansible executable.",
     ):
-        ansible_version()
+        # bypassing lru cache
+        ansible_version.__wrapped__()
